@@ -14,11 +14,10 @@ from aiohttp import ClientWebSocketResponse
 from mi import Instance, InstanceMeta, User, config
 from mi.chat import Chat
 from mi.drive import Drive
-from mi.exception import InvalidParameters
 from mi.http import HTTPClient
 from mi.note import Note
 from mi.state import ConnectionState
-from mi.utils import api, get_module_logger
+from mi.utils import get_module_logger
 from .gateway import MisskeyWebSocket
 
 if TYPE_CHECKING:
@@ -28,6 +27,7 @@ if TYPE_CHECKING:
 class Client:
     def __init__(self, loop: Optional[asyncio.AbstractEventLoop] = None, **options: Dict[Any, Any]):
         super().__init__(**options)
+        self.url = None
         self.extra_events: Dict[str, Any] = {}
         self.special_events: Dict[str, Any] = {}
         self.token: Optional[str] = None
@@ -41,7 +41,7 @@ class Client:
         self.ws: MisskeyWebSocket = None
 
     def _get_state(self, **options: Any) -> ConnectionState:
-        return ConnectionState(dispatch=self.dispatch, http=self.http, loop=self.loop, **options)
+        return ConnectionState(dispatch=self.dispatch, http=self.http, loop=self.loop, client=self, **options)
 
     async def on_ready(self, ws: ClientWebSocketResponse):
         """
@@ -150,14 +150,19 @@ class Client:
             except asyncio.CancelledError:
                 pass
 
-    async def _on_message(self, message):
-        await self.dispatch("message", message)
-
     @staticmethod
     async def __on_error(event_method: str) -> None:
         print(f"Ignoring exception in {event_method}", file=sys.stderr)
         traceback.print_exc()
 
+    async def progress_command(self, message):
+        for key, command in self.all_commands.items():
+            if re.search(command.regex, message.content):
+                await command.invoke(message)
+
+    async def on_mention(self, message):
+        await self.progress_command(message)
+
     async def on_error(self, err):
         await self.event_dispatch("error", err)
 
@@ -217,8 +222,10 @@ class Client:
             since_date: int = 0,
             until_data: int = 0
     ) -> AsyncIterator[Note]:
-        return self._connection.get_user_notes(user_id=user_id, since_id=since_id, include_my_renotes=include_my_renotes, include_replies=include_replies, with_files=with_files,
-                                               until_id=until_id, limit=limit, get_all=get_all, exclude_nsfw=exclude_nsfw, file_type=file_type, since_date=since_date, until_data=until_data)
+        return self._connection.get_user_notes(user_id=user_id, since_id=since_id, include_my_renotes=include_my_renotes,
+                                               include_replies=include_replies, with_files=with_files,
+                                               until_id=until_id, limit=limit, get_all=get_all, exclude_nsfw=exclude_nsfw,
+                                               file_type=file_type, since_date=since_date, until_data=until_data)
 
     async def get_instance(self, host: Optional[str] = None) -> Union[Instance, InstanceMeta]:
         """
@@ -293,7 +300,7 @@ class Client:
         await self._connection.fetch_user(user_id=user_id, username=username, host=host)
 
     async def file_upload(
-        self,
+            self,
             name: Optional[str] = None,
             to_file: Optional[str] = None,
             to_url: Optional[str] = None,
@@ -321,7 +328,8 @@ class Client:
             upload後のレスポンスをDrive型に変更して返します
         """
 
-        return await self._connection.file_upload(name=name, to_file=to_file, to_url=to_url, force=force, is_sensitive=is_sensitive)
+        return await self._connection.file_upload(name=name, to_file=to_file, to_url=to_url, force=force,
+                                                  is_sensitive=is_sensitive)
 
     async def show_file(self, file_id: Optional[str] = None, url: Optional[str] = None) -> Drive:
         """
@@ -368,7 +376,14 @@ class Client:
                                                 poll=poll)
 
     async def get_announcements(self, limit: int, with_unreads: bool, since_id: str, until_id: str):
-        return await self._connection.get_announcements(limit=limit, with_unreads=with_unreads, since_id=since_id, until_id=until_id)
+        return await self._connection.get_announcements(limit=limit, with_unreads=with_unreads, since_id=since_id,
+                                                        until_id=until_id)
+
+    async def get_note(self, note_id: str) -> Note:
+        return await self._connection.get_note(note_id=note_id)
+
+    async def get_replies(self, note_id: str, since_id: Optional[str] = None, until_id: Optional[str] = None, limit: int = 1) -> List[Note]:
+        return await self._connection.get_replies(note_id=note_id, limit=limit, since_id=since_id, until_id=until_id)
 
     async def login(self, token):
 
@@ -382,7 +397,7 @@ class Client:
         while True:
             await self.ws.poll_event()
 
-    async def start(self, url: str, token: str, *, debug: bool = False, recconect: bool = True, timeout: int = 60):
+    async def start(self, url: str, token: str, *, debug: bool = False, reconnect: bool = True, timeout: int = 60):
         """
         Starting Bot
 
@@ -394,7 +409,7 @@ class Client:
             User Token
         debug: bool, default False
             debugging mode
-        recconect: bool, default True
+        reconnect: bool, default True
             coming soon...
         timeout: int, default 60
             Time until websocket times out
@@ -419,4 +434,4 @@ class Client:
         config.i = config.Config(**auth_i)
         config.debug = debug
         await self.login(token)
-        await self.connect(reconnect=recconect, timeout=timeout)
+        await self.connect(reconnect=reconnect, timeout=timeout)
