@@ -6,11 +6,7 @@ from mi import Emoji, utils
 from mi.exception import NotExistRequiredData
 from mi.user import User
 from .abc.note import AbstractNote
-from .types.note import (Note as NotePayload,
-                         Poll as PollPayload,
-                         Renote as RenotePayload,
-                         Reaction as ReactionPayload
-                         )
+from .types.note import (Note as NotePayload, Poll as PollPayload, Reaction as ReactionPayload, Renote as RenotePayload)
 
 if TYPE_CHECKING:
     from mi import ConnectionState
@@ -331,26 +327,61 @@ class Note(AbstractNote):
 
         return await self._state.add_note_to_clips(clip_id=clip_id, note_id=self.id)
 
-    async def create_renotes(            self, content: Optional[str],
-            cw: Optional[str] = None,
-            no_extract_mentions: bool = False,
-            no_extract_hashtags: bool = False,
-            no_extract_emojis: bool = False,
-            reply_id: Optional[str] = None,
-            channel_id: Optional[str] = None,
-            file_ids=None,
-            poll: Optional[Poll] = None
-            ) -> Note:
+    async def create_renote(self) -> Note:
         """
         ノートをリノートします
+        """
+
+        return await self._state.create_renote(self.id)
+
+    async def get_replies(self, since_id: Optional[str] = None, until_id: Optional[str] = None, limit: int = 10) -> List[Note]:
+        """
+        ノートに対する返信を取得します
+        """
+
+        return await self._state.get_replies(note_id=self.id, since_id=since_id, until_id=until_id, limit=limit)
+
+    async def create_quote(self,
+                           content: Optional[str] = None,
+                           visibility: str = None,
+                           visible_user_ids: Optional[List[str]] = None,
+                           cw: Optional[str] = None,
+                           local_only: bool = False,
+                           no_extract_mentions: bool = False,
+                           no_extract_hashtags: bool = False,
+                           no_extract_emojis: bool = False,
+                           file_ids=None,
+                           poll: Optional[Poll] = None):
+        """
+        ノートを引用して新規にノートを投稿します
 
         Parameters
         ----------
-        limit: int, default=10
-            謎
-        since_id: Optional[str], default=None
-            謎
-        until_id: Optional[str], default=None
-            謎
+        content: Optional[str], default=None
+            引用に対するテキスト
+        visibility: str, default=None
+            ノートの公開範囲
+        visible_user_ids: Optional[List[str]]
+            ノートの公開対象になるユーザーid
+        cw: Optional[str]
+            閲覧注意の文字列
+        local_only: bool
+            ローカルにのみ公開するかどうか
+        no_extract_mentions: bool
+            メンションを展開するかどうか
+        no_extract_hashtags: bool
+            ハッシュタグを展開するかどうか
+        no_extract_emojis: bool
+            絵文字を展開するかどうか
+        file_ids:
+            添付するファイルのid
+        poll: Optional[Poll]
+            アンケート
         """
-        return await self._state.post_note()
+
+        visibility = self.visibility or visibility or 'public'
+        return await self._state.create_quote(content=content, visibility=visibility, visible_user_ids=visible_user_ids, cw=cw,
+                                              local_only=local_only, no_extract_mentions=no_extract_mentions,
+                                              no_extract_hashtags=no_extract_hashtags,
+                                              no_extract_emojis=no_extract_emojis, note_id=self.id, file_ids=file_ids,
+                                              poll=poll)
