@@ -10,17 +10,17 @@ from aiocache.factory import Cache
 from mi import Instance, InstanceMeta, User
 from mi.chat import Chat
 from mi.drive import Drive
+from mi.emoji import Emoji
 from mi.exception import ContentRequired, InvalidParameters, NotExistRequiredParameters
 from mi.http import Route
 from mi.iterators import InstanceIterator
 from mi.note import Note, Poll, Reaction
 from mi.user import Follower, Following
-from mi.emoji import Emoji
 from mi.utils import check_multi_arg, get_cache_key, get_module_logger, key_builder, remove_dict_empty, str_lower, \
     upper_to_lower
 
 if TYPE_CHECKING:
-    from mi import HTTPClient
+    from mi import HTTPClient, Client
     from mi.types import (Note as NotePayload, Chat as ChatPayload)
 
 
@@ -45,6 +45,124 @@ class NoteActions:
         data = {'noteId': note_id, 'reaction': reaction}
         return bool(await self.http.request(Route('POST', '/api/reactions/create', json=data, auth=True)))
 
+    async def post_note(self,
+                        content: Optional[str] = None,
+                        visibility: str = "public",
+                        visible_user_ids: Optional[List[str]] = None,
+                        cw: Optional[str] = None,
+                        local_only: bool = False,
+                        no_extract_mentions: bool = False,
+                        no_extract_hashtags: bool = False,
+                        no_extract_emojis: bool = False,
+                        reply_id: Optional[str] = None,
+                        renote_id: Optional[str] = None,
+                        channel_id: Optional[str] = None,
+                        file_ids=None,
+                        poll: Optional[Poll] = None
+                        ):
+        """
+
+        ノートを投稿します。
+
+        Parameters
+        ----------
+        content : str
+            投稿する内容
+        visibility : str, optional
+            公開範囲, by default "public"
+        visible_user_ids : Optional[List[str]], optional
+            公開するユーザー, by default None
+        cw : Optional[str], optional
+            閲覧注意の文字, by default None
+        local_only : bool, optional
+            ローカルにのみ表示するか, by default False
+        no_extract_mentions : bool, optional
+            メンションを展開するか, by default False
+        no_extract_hashtags : bool, optional
+            ハッシュタグを展開するか, by default False
+        no_extract_emojis : bool, optional
+            絵文字を展開するか, by default False
+        reply_id : Optional[str], optional
+            リプライ先のid, by default None
+        renote_id : Optional[str], optional
+            リノート先のid, by default None
+        channel_id : Optional[str], optional
+            チャンネルid, by default None
+        file_ids : [type], optional
+            添付するファイルのid, by default None
+        poll : Optional[Poll], optional
+            アンケート, by default None
+
+        Returns
+        -------
+        [type]
+            [description]
+
+        Raises
+        ------
+        ContentRequired
+            [description]
+        """
+        if file_ids is None:
+            file_ids = []
+        field = {
+            "visibility": visibility,
+            "visibleUserIds": visible_user_ids,
+            "text": content,
+            "cw": cw,
+            "localOnly": local_only,
+            "noExtractMentions": no_extract_mentions,
+            "noExtractHashtags": no_extract_hashtags,
+            "noExtractEmojis": no_extract_emojis,
+            "replyId": reply_id,
+            "renoteId": renote_id,
+            "channelId": channel_id
+        }
+        if not check_multi_arg(content, file_ids, renote_id, poll):
+            raise ContentRequired("ノートの送信にはcontent, file_ids, renote_id またはpollのいずれか1つが無くてはいけません")
+
+        if poll and type(Poll):
+            poll_data = remove_dict_empty({
+                'choices': poll.choices,
+                'multiple': poll.multiple,
+                'expiresAt': poll.expires_at,
+                'expiredAfter': poll.expired_after
+            })
+            field["poll"] = poll_data
+
+        if file_ids:
+            field["fileIds"] = file_ids
+        field = remove_dict_empty(field)
+        res = await self.http.request(Route('POST', '/api/notes/create'), json=field, auth=True, lower=True)
+        return Note(res["created_note"], state=self)
+
+    async def create_renote(self, note_id: str) -> Note:
+        return await self.post_note(renote_id=note_id)
+
+    async def create_quote(self, note_id: str,
+                           content: Optional[str] = None,
+                           visibility: str = 'public',
+                           visible_user_ids: Optional[List[str]] = None,
+                           cw: Optional[str] = None,
+                           local_only: bool = False,
+                           no_extract_mentions: bool = False,
+                           no_extract_hashtags: bool = False,
+                           no_extract_emojis: bool = False,
+                           file_ids=None,
+                           poll: Optional[Poll] = None) -> Note:
+        return await self.post_note(content=content, visibility=visibility, visible_user_ids=visible_user_ids, cw=cw,
+                                    local_only=local_only, no_extract_mentions=no_extract_mentions,
+                                    no_extract_hashtags=no_extract_hashtags,
+                                    no_extract_emojis=no_extract_emojis, renote_id=note_id, file_ids=file_ids, poll=poll)
+
+    async def get_note(self, note_id) -> Note:
+        res = await self.http.request(Route('POST', '/api/notes/show'), json={"noteId": note_id}, auth=True, lower=True)
+        return Note(res, state=self)
+
+    async def get_replies(self, note_id: str, since_id: Optional[str] = None, until_id: Optional[str] = None, limit: int = 10,) -> List[Note]:
+        res = await self.http.request(Route('POST', '/api/notes/replies'), json={"noteId": note_id, "sinceId": since_id, "untilId": until_id, "limit": limit}, auth=True, lower=True)
+        return [Note(i, state=self) for i in res]
+
 
 class UserAction:
     def __init__(self, http: HTTPClient, loop: asyncio.AbstractEventLoop):
@@ -65,8 +183,9 @@ class ClientAction(NoteActions, UserAction):
 
 
 class ConnectionState(ClientAction):
-    def __init__(self, dispatch: Callable[..., Any], http: HTTPClient, loop: asyncio.AbstractEventLoop):
+    def __init__(self, dispatch: Callable[..., Any], http: HTTPClient, loop: asyncio.AbstractEventLoop, client: Client):
         super().__init__(http, loop)
+        self.client: Client = client
         self.dispatch = dispatch
         self.http: HTTPClient = http
         self.logger = get_module_logger(__name__)
@@ -128,7 +247,7 @@ class ConnectionState(ClientAction):
         ユーザーをフォローした際のイベントを解析する関数
         """
 
-        # self.dispatch('follow', Follower(message, state=self))
+        self.dispatch('user_follow', User(message, state=self))
 
     def parse_followed(self, message: Dict[str, Any]) -> None:
         """
@@ -141,6 +260,7 @@ class ConnectionState(ClientAction):
         """
         メンションイベントを解析する関数
         """
+
         self.dispatch('mention', Note(message, state=self))
 
     def parse_drive_file_created(self, message: Dict[str, Any]) -> None:
@@ -189,8 +309,10 @@ class ConnectionState(ClientAction):
         -------
         None
         """
-        #notification_type = str_lower(message['type'])
-        #getattr(self, f'parse_{notification_type}')(message)
+        accept_type = ['reaction']
+        notification_type = str_lower(message['type'])
+        if notification_type in accept_type:
+            getattr(self, f'parse_{notification_type}')(message)
 
     def parse_follow_request_accepted(self, message: Dict[str, Any]) -> None:
         pass
@@ -207,8 +329,8 @@ class ConnectionState(ClientAction):
         message : Dict[str, Any]
             Received message
         """
-        #notification_type = str_lower(message['type'])
-        #getattr(self, f'parse_{notification_type}')(message)
+        # notification_type = str_lower(message['type'])
+        # getattr(self, f'parse_{notification_type}')(message)
 
     def parse_reaction(self, message: Dict[str, Any]) -> None:
         """
@@ -222,7 +344,7 @@ class ConnectionState(ClientAction):
         """
         note = Note(message, state=self)
         # Router(self.http.ws).capture_message(note.id) TODO: capture message
-        self.dispatch('message', note)
+        self.client._on_message(note)
 
     async def follow_user(self, user_id: str) -> tuple[bool, Optional[str]]:
         """
@@ -414,90 +536,6 @@ class ConnectionState(ClientAction):
         await old_cache.delete(kwargs['cache_key'].format('get_user'))
         return User(data, state=self)
 
-    async def post_note(self,
-                        content: Optional[str] = None,
-                        visibility: str = "public",
-                        visible_user_ids: Optional[List[str]] = None,
-                        cw: Optional[str] = None,
-                        local_only: bool = False,
-                        no_extract_mentions: bool = False,
-                        no_extract_hashtags: bool = False,
-                        no_extract_emojis: bool = False,
-                        reply_id: Optional[str] = None,
-                        renote_id: Optional[str] = None,
-                        channel_id: Optional[str] = None,
-                        file_ids=None,
-                        poll: Optional[Poll] = None
-                        ):
-        """
-
-        ノートを投稿します。
-
-        Parameters
-        ----------
-        content : str
-            投稿する内容
-        visibility : str, optional
-            公開範囲, by default "public"
-        visible_user_ids : Optional[List[str]], optional
-            公開するユーザー, by default None
-        cw : Optional[str], optional
-            閲覧注意の文字, by default None
-        local_only : bool, optional
-            ローカルにのみ表示するか, by default False
-        no_extract_mentions : bool, optional
-            メンションを展開するか, by default False
-        no_extract_hashtags : bool, optional
-            ハッシュタグを展開するか, by default False
-        no_extract_emojis : bool, optional
-            絵文字を展開するか, by default False
-        reply_id : Optional[str], optional
-            リプライ先のid, by default None
-        renote_id : Optional[str], optional
-            リノート先のid, by default None
-        channel_id : Optional[str], optional
-            チャンネルid, by default None
-        file_ids : [type], optional
-            添付するファイルのid, by default None
-        poll : Optional[Poll], optional
-            アンケート, by default None
-
-        Returns
-        -------
-        [type]
-            [description]
-
-        Raises
-        ------
-        ContentRequired
-            [description]
-        """
-        if file_ids is None:
-            file_ids = []
-        field = {
-            "visibility": visibility,
-            "visibleUserIds": visible_user_ids,
-            "text": content,
-            "cw": cw,
-            "localOnly": local_only,
-            "noExtractMentions": no_extract_mentions,
-            "noExtractHashtags": no_extract_hashtags,
-            "noExtractEmojis": no_extract_emojis,
-            "replyId": reply_id,
-            "renoteId": renote_id,
-            "channelId": channel_id
-        }
-        if not check_multi_arg(content, file_ids, renote_id, poll):
-            raise ContentRequired("ノートの送信にはcontent, file_ids, renote_id またはpollのいずれか1つが無くてはいけません")
-
-        if poll and len(poll.choices) > 0:
-            field["poll"] = poll
-        if file_ids:
-            field["fileIds"] = file_ids
-        field = remove_dict_empty(field)
-        res = await self.http.request(Route('POST', '/api/notes/create'), json=field, auth=True, lower=True)
-        return Note(res["created_note"], state=self)
-
     async def get_followers(
             self,
             user_id: Optional[str] = None,
@@ -586,26 +624,27 @@ class ConnectionState(ClientAction):
 
     async def show_file(self, file_id: Optional[str], url: Optional[str]) -> Drive:
         data = remove_dict_empty({"fileId": file_id, "url": url})
-        return Drive(await self.http.request(Route('POST', '/api/admin/drive/show-file'), json=data, auth=True, lower=True), state=self)
+        return Drive(await self.http.request(Route('POST', '/api/admin/drive/show-file'), json=data, auth=True, lower=True),
+                     state=self)
 
     async def remove_file(self, file_id: str) -> bool:
         return bool(await self.http.request(Route('POST', '/api/drive/files/delete'), json={'fileId': file_id}, auth=True))
 
     async def get_user_notes(
-        self,
-        user_id: str,
-        *,
-        since_id: Optional[str] = None,
-        include_my_renotes: bool = True,
-        include_replies: bool = True,
-        with_files: bool = False,
-        until_id: Optional[str] = None,
-        limit: int = 10,
-        get_all: bool = False,
-        exclude_nsfw: bool = True,
-        file_type: Optional[List[str]] = None,
-        since_date: int = 0,
-        until_data: int = 0
+            self,
+            user_id: str,
+            *,
+            since_id: Optional[str] = None,
+            include_my_renotes: bool = True,
+            include_replies: bool = True,
+            with_files: bool = False,
+            until_id: Optional[str] = None,
+            limit: int = 10,
+            get_all: bool = False,
+            exclude_nsfw: bool = True,
+            file_type: Optional[List[str]] = None,
+            since_date: int = 0,
+            until_data: int = 0
     ) -> AsyncIterator[Note]:
         if limit > 100:
             raise InvalidParameters("limit は100以上を受け付けません")
