@@ -1,11 +1,11 @@
 from __future__ import annotations
+
 from typing import Any, AsyncIterator, Dict, List, Optional, TYPE_CHECKING
 
-from pydantic import BaseModel
-
 from mi import Instance
-from mi.drive import File
-from mi.types.user import (User as UserPayload)
+from mi.emoji import Emoji
+from mi.types.user import (Channel as ChannelPayload, FieldContent as FieldContentPayload, PinnedNote as PinnedNotePayload,
+                           PinnedPage as PinnedPagePayload, User as UserPayload)
 
 if TYPE_CHECKING:
     from mi import ConnectionState
@@ -22,8 +22,9 @@ class Follower:
         self.user: User = User(data['follower'], state=state)
         self._state = state
 
+
 class Following:
-    def __init__(self, data, state:ConnectionState):
+    def __init__(self, data, state: ConnectionState):
         self.id = data['id']
         self.name = data['name']
         self.username = data['username']
@@ -37,75 +38,81 @@ class Following:
         self.is_bot = bool(data['is_bot'])
         self.is_cat = bool(data['is_cat'])
         self._state = state
-    
+
     async def accept_request(self) -> bool:
         return await self._state.accept_following_request(self.id)
-    
+
     async def reject_request(self) -> bool:
         return await self._state.reject_following_request(self.id)
-    
-
-class Channel(BaseModel):
-    id: Optional[str] = None
-    createdAt: Optional[str] = None
-    lastNotedAt: Optional[str] = None
-    name: Optional[str] = None
-    description: Optional[str] = None
-    bannerUrl: Optional[str] = None
-    notesCount: Optional[int] = 0
-    usersCount: Optional[int] = 0
-    isFollowing: Optional[bool] = False
-    userId: Optional[str] = None
 
 
-class PinnedNote(BaseModel):
-    id: Optional[str] = None
-    createdAt: Optional[str] = None
-    text: Optional[str] = None
-    cw: Optional[str] = None
-    userId: Optional[str] = None
-    user: Optional[Dict[str, Any]] = {}
-    replyId: Optional[str] = None
-    renoteId: Optional[str] = None
-    reply: Optional[Dict[str, Any]] = {}
-    renote: Optional[Dict[str, Any]] = {}
-    viaMobile: Optional[bool] = False
-    isHidden: Optional[bool] = False
-    visibility: Optional[str] = None
-    mentions: Optional[List[str]] = []
-    visibleUserIds: Optional[List[str]] = []
-    fileIds: Optional[List[str]] = []
-    files: Optional[List[File]] = []
-    tags: Optional[List[str]] = []
-    poll: Optional[Dict[str, Any]] = {}
-    channelId: Optional[str] = None
-    channel: Optional[Channel] = Channel()
-    localOnly: Optional[bool] = False
-    # emojis: Optional[List[Emoji]] # TODO: 2021 修正
-    reactions: Optional[Dict[str, Any]] = {}
-    renoteCount: Optional[int] = 0
-    repliesCount: Optional[int] = 0
-    uri: Optional[str] = None
-    url: Optional[str] = None
-    myReaction: Optional[Dict[str, Any]] = {}
+class Channel:
+    def __init__(self, data: ChannelPayload, state: ConnectionState):
+        self.id: Optional[str] = data.get("id")
+        self.created_at: Optional[str] = data.get("created_at")
+        self.last_noted_at: Optional[str] = data.get("last_noted_at")
+        self.name: Optional[str] = data.get("name")
+        self.description: Optional[str] = data.get("description")
+        self.banner_url: Optional[str] = data.get("banner_url")
+        self.notes_count: Optional[int] = data.get("notes_count")
+        self.users_count: Optional[int] = data.get("users_count")
+        self.is_following: Optional[bool] = data.get("is_following")
+        self.user_id: Optional[str] = data.get("user_id")
+        self._state = state
 
 
-class PinnedPage(BaseModel):
-    id: Optional[str] = None
-    created_at: Optional[str] = None
-    updated_at: Optional[str] = None
-    title: Optional[str] = None
-    name: Optional[str] = None
-    summary: Optional[str] = None
-    content: Optional[List] = []
-    variables: Optional[List] = []
-    user_id: Optional[str] = None
-    author: Optional[Dict[str, Any]] = {}
+class PinnedNote:
+    def __init__(self, data: PinnedNotePayload, state: ConnectionState):
+        self.id: Optional[str] = data.get("id")
+        self.created_at: Optional[str] = data.get("created_at")
+        self.text: Optional[str] = data.get("text")
+        self.cw: Optional[str] = data.get("cw")
+        self.user_id: Optional[str] = data.get("user_id")
+        self.user: Optional[User] = User(data["user"], state=state) if data.get('user') else None
+        self.reply_id: Optional[str] = data.get("reply_id")
+        self.reply: Optional[Dict[str, Any]] = data.get("reply")
+        self.renote: Optional[Dict[str, Any]] = data.get("renote")
+        self.via_mobile: Optional[bool] = data.get("via_mobile")
+        self.is_hidden: Optional[bool] = data.get("is_hidden")
+        self.visibility: Optional[bool] = bool(data["visibility"]) if data.get("visibility") else None
+        self.mentions: Optional[List[str]] = data.get("mentions")
+        self.visible_user_ids: Optional[List[str]] = data.get("visible_user_ids")
+        self.file_ids: Optional[List[str]] = data.get("file_ids")
+        self.files: Optional[List[str]] = data.get("files")
+        self.tags: Optional[List[str]] = data.get("tags")
+        self.poll: Optional[List[str]] = data.get("poll")
+        self.channel: Optional[Channel] = Channel(data["channel"], state=state) if data.get("channel") else None
+        self.local_only: Optional[bool] = data.get("local_only")
+        self.emojis: Optional[List[Emoji]] = [Emoji(i, state=state) for i in data["emojis"]] if data.get("emojis") else None
+        self.reactions: Optional[Dict[str, Any]] = data.get("reactions")
+        self.renote_count: Optional[int] = data.get("renote_count")
+        self.replies_count: Optional[int] = data.get("replies_count")
+        self.uri: Optional[str] = data.get("uri")
+        self.url: Optional[str] = data.get("url")
+        self.my_reaction: Optional[Dict[str, Any]] = data.get("my_reaction")
+        self._state: ConnectionState = state
 
 
-class FieldContent(BaseModel):
-    name: str
-    value: str
+class PinnedPage:
+    def __init__(self, data: PinnedPagePayload, state: ConnectionState):
+        self.id: Optional[str] = data.get("id")
+        self.created_at: Optional[str] = data.get("created_at")
+        self.updated_at: Optional[str] = data.get("updated_at")
+        self.title: Optional[str] = data.get("title")
+        self.name: Optional[str] = data.get("name")
+        self.summary: Optional[str] = data.get("summary")
+        self.content: Optional[List] = data.get("content")
+        self.variables: Optional[List] = data.get("variables")
+        self.user_id: Optional[str] = data.get("user_id")
+        self.author: Optional[Dict[str, Any]] = data.get("author")
+        self._state: ConnectionState = state
+
+
+class FieldContent:
+    def __init__(self, data: FieldContentPayload, state: ConnectionState):
+        self.name: str = data["name"]
+        self.value: str = data["value"]
+        self._state: ConnectionState = state
 
 
 class UserDetails:
@@ -167,11 +174,11 @@ class User:
         アカウントの作成日
     updated_at: str
         アカウントの更新日(ノートを投稿するなど)
-    locked: bool
+    is_locked: bool
         アカウントがロックされているか
-    silienced: bool
+    is_silenced: bool
         アカウントがミュートされているか
-    suspended: bool
+    is_suspended: bool
         アカウントが凍結されているか
     description: str
         アカウントの概要
@@ -195,15 +202,15 @@ class User:
         ピン留めされたページ
     ff_visibility: str
         ノートの投稿範囲
-    following: bool
+    is_following: bool
         ユーザーがフォローしているかどうか
-    followed: bool
+    is_follow: bool
         ユーザーのことをフォローしているかどうか
-    blocking: bool
+    is_blocking: bool
         ユーザーが自分のことをブロックしているかどうか
-    blocked: bool
+    is_blocked: bool
         ユーザーのことをブロックしているかどうか
-    muted:bool
+    is_muted: bool
         ユーザーのことをミュートしているかどうか
     instance: Any
         ユーザーのインスタンス
@@ -228,9 +235,9 @@ class User:
         self.uri: Optional[str] = data.get("uri")
         self.created_at = data.get("created_at")
         self.updated_at = data.get("updated_at")
-        self.locked = data.get("is_locked", False)
-        self.silenced = data.get("is_silenced", False)
-        self.suspended = data.get("is_suspended", False)
+        self.is_locked = data.get("is_locked", False)
+        self.is_silenced = data.get("is_silenced", False)
+        self.is_suspended = data.get("is_suspended", False)
         self.description = data.get("description")
         self.location = data.get("location")
         self.birthday = data.get("birthday")
@@ -243,11 +250,11 @@ class User:
         self.pinned_page_id = data.get("pinned_page_id")
         self.pinned_page = data.get("pinned_page")
         self.ff_visibility: str = data.get("ff_visibility", 'public')
-        self.following: bool = bool(data.get("is_following", False))
-        self.followed: bool = bool(data.get("is_follow", False))
-        self.blocking: bool = bool(data.get("is_blocking", False))
-        self.blocked: bool = bool(data.get("is_blocked", False))
-        self.muted: bool = bool(data.get("is_muted", False))
+        self.is_following: bool = bool(data.get("is_following", False))
+        self.is_follow: bool = bool(data.get("is_follow", False))
+        self.is_blocking: bool = bool(data.get("is_blocking", False))
+        self.is_blocked: bool = bool(data.get("is_blocked", False))
+        self.is_muted: bool = bool(data.get("is_muted", False))
         self.details = UserDetails(data)
         self._state = state
 
@@ -295,7 +302,7 @@ class User:
     def get_followers(self, until_id: Optional[str] = None, limit: int = 10, get_all: bool = False) -> AsyncIterator[Follower]:
         """
         ユーザーのフォロワー一覧を取得します
-        
+
         Parameters
         ----------
         until_id : str, default=None
