@@ -5,17 +5,18 @@ import json
 import logging
 import re
 from inspect import isawaitable
-from typing import Any, Callable, Dict, Iterable, List, Optional, TypeVar, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, TypeVar
 
 import emoji
 
-from mi import config, exception
+from mi import config
 
 T = TypeVar("T")
 
+
 def deprecated_func(func):
     print('deprecated function:' + func.__name__)
-    
+
 
 def get_cache_key(func):
     async def decorator(self, *args, **kwargs):
@@ -131,14 +132,6 @@ def find(predicate: Callable[[T], Any], seq: Iterable[T]) -> Optional[T]:
 def json_dump(data, *args, **kwargs):
     return json.dumps(data, ensure_ascii=False, *args, **kwargs)
 
-@deprecated_func
-def api(*args, **kwargs) -> None:
-    """
-    .. deprecated:: 1.0.1
-        この関数は廃止され、現在は使用できません。互換性のため名前空間のみが提供されています。
-        今後は :func:`request` を使用してください
-    """
-
 
 def remove_list_empty(data: List[Any]) -> List[Any]:
     """
